@@ -90,13 +90,13 @@ private:
 
 
 private:
-    Ui_QueryOptions* ui_queryOptions;
-    TMDBModel* m_model;
-    TMResultsSortFilterProxyModel *m_proxyModel;
-    QaView* m_qaView;
+    Ui_QueryOptions* ui_queryOptions{};
+    TMDBModel* m_model{};
+    TMResultsSortFilterProxyModel *m_proxyModel{};
+    QaView* m_qaView{};
 
-    DocPosition::Part m_partToAlsoTryLater;
-    int m_dbusId;
+    DocPosition::Part m_partToAlsoTryLater{DocPosition::UndefPart};
+    int m_dbusId{-1};
     static QList<int> ids;
 };
 
@@ -166,9 +166,9 @@ private:
     int translationStatus(const QModelIndex& item) const;
 
 private:
-    QueryType m_queryType;
+    QueryType m_queryType{WordOrder};
     QString m_dbName;
-    int m_totalResultCount;
+    int m_totalResultCount{0};
 public:
     mutable QMutex m_dbOperationMutex;
 };
